#include <stdlib.h>
#include <stdio.h>

#define MAX 1000000

struct point {
  int x;
  int y;
  int next;
  bool del;
};

int cmp (void const * a, void const * b) {
  int ax = ((point const *)a)->x;
  int bx = ((point const *)b)->x;
  if (ax < bx) return -1;
  if (ax > bx) return +1;
  int ay = ((point const *)a)->y;
  int by = ((point const *)b)->y;
  if (ay < by) return -1;
  if (ay > by) return +1;
  return 0;
};

point T[1 + MAX]; // elem 0 used only for T[0].next == head

long long dir (int i, int j, int k) {
  int xj = T[j].x;
  int yj = T[j].y;
  return (T[i].x - xj) * 1LL * (T[k].y - yj)
       - (T[k].x - xj) * 1LL * (T[i].y - yj);
};

int TS[MAX]; int TSff; // Left-Top ConvexHull
int BS[MAX]; int BSff; // Bottom-Right ConvexHull

bool getlayer (void) {
  TSff = BSff = 0;
  for (int p = 0, q; (q = T[p].next); ) if (T[q].del) {
    T[p].next = T[q].next;
  } else {
    p = q;
    while ((TSff >= 2) && (dir(TS[TSff - 2], TS[TSff - 1], p) < 0)) --TSff; TS[TSff++] = p;
    while ((BSff >= 2) && (dir(BS[BSff - 2], BS[BSff - 1], p) > 0)) --BSff; BS[BSff++] = p;
  };

#ifdef DEBUG
  printf("[TS:%d |", TSff);
  for (int i = 0; i < TSff; ++i) printf(" %d:%d,%d", i, T[TS[i]].x, T[TS[i]].y);
  printf("]\n");

  printf("[BS:%d |", BSff);
  for (int i = 0; i < BSff; ++i) printf(" %d:%d,%d", i, T[BS[i]].x, T[BS[i]].y);
  printf("]\n");
#endif /* DEBUG */
  
  for (int i = 0; i < TSff; ++i) T[TS[i]].del = true;
  for (int i = 0; i < BSff; ++i) T[BS[i]].del = true;
  return TSff + BSff;
};

int main (void) {
  int d;
  scanf("%d", &d);
  while (d--) {
    int n;
    scanf("%d", &n);
    for (int i = 1; i <= n; ++i) scanf("%d%d", &T[i].x, &T[i].y);
    qsort(&T[1], n, sizeof(T[0]), cmp);
    for (int i = 1; i <= n; ++i) {
      T[i].del = false;
      T[i].next = i + 1;
    };    
    T[0].next = 1; // T[0].next is the single linked list head pointer
    T[n].next = 0; // after setting head so n==0 works
    
    int dups = 0;
    for (int i = 2; i <= n; ++i) {
      if (T[i - 1].x != T[i].x) continue;
      if (T[i - 1].y != T[i].y) continue;
      T[i].del = true;
      ++dups;
    };
    if (dups) fprintf(stderr, "WARNING!!! Removed %d duplicates.\n", dups);

    int layers = 0;
    while (getlayer()) ++layers;
    printf("%d\n", layers);
  };
  return 0;
};
